-- Create syntax for TABLE 'dc_alarm_bind'
CREATE TABLE `dc_alarm_bind` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` int(11) NOT NULL,
                                 `item` int(11) NOT NULL,
                                 `threshold` varchar(20) DEFAULT NULL COMMENT '阈值配置 [min,max,连续采样次数], 为 null 表示不设置',
                                 `slope` varchar(20) DEFAULT NULL COMMENT '斜率变化配置 [数据量,阈值,连续采样次数], 为 null 表示不设置',
                                 `na` varchar(20) DEFAULT NULL COMMENT 'na报警 [数据量, na数据量,连续采样次数], 为 null 表示不设置',
                                 `interval` int(11) NOT NULL DEFAULT '0' COMMENT '检测周期 时间 s',
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`device_code`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;

-- Create syntax for TABLE 'dc_alarm_list'
CREATE TABLE `dc_alarm_list` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(50) NOT NULL DEFAULT '',
                                 `item` varchar(50) NOT NULL DEFAULT '',
                                 `val` varchar(20) NOT NULL DEFAULT '' COMMENT '报警发生时，点位的值',
                                 `alarm_id` int(11) NOT NULL COMMENT '报警 ID dc_alarm_bind.id',
                                 `title` varchar(100) NOT NULL DEFAULT '' COMMENT '报警标题',
                                 `context` varchar(255) NOT NULL DEFAULT '' COMMENT '报警内容',
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`device_code`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_app_info'
CREATE TABLE `dc_app_info` (
                               `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                               `app_name` varchar(30) NOT NULL DEFAULT '' COMMENT '应用名称',
                               `project_id` int(11) NOT NULL DEFAULT '0' COMMENT '限定服务的project_id',
                               `secret` varchar(32) NOT NULL DEFAULT '' COMMENT '数据签名的secret',
                               `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '状态 0: 正常 1: 禁用',
                               `m_time` timestamp NOT NULL COMMENT '更新时间',
                               PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                               UNIQUE KEY `app_name` (`app_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;

-- Create syntax for TABLE 'dc_clean_bind'
CREATE TABLE `dc_clean_bind` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(50) NOT NULL DEFAULT '',
                                 `item` varchar(50) NOT NULL DEFAULT '',
                                 `range_na` varchar(100) NOT NULL DEFAULT '' COMMENT '被当做 na 的值范围，使用逗号分隔多个值 例： '''', ''-'', ''null''',
                                 `dropna` tinyint(1) NOT NULL COMMENT '为 na 时，是否进行删除操作 0： 否 1： 是',
                                 `fillna` tinyint(1) NOT NULL COMMENT '为 na 时，是否进行数据填充 0:  否 1： 是',
                                 `fillna_way` char(10) NOT NULL DEFAULT '' COMMENT '当 fillna 为 1 时， 为数据指定填充方式 【默认值 ｜ 中位数 ｜ 众数 ｜ 平均数 ｜ 自定义】',
                                 `drop_solitude` int(11) NOT NULL DEFAULT '0' COMMENT '是否删除离群点',
                                 `duplicate` tinyint(1) NOT NULL COMMENT '是否进行去重复操作 0:  否 1： 是',
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 UNIQUE KEY `project_id` (`project_id`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=30002;

-- Create syntax for TABLE 'dc_clean_quality'
CREATE TABLE `dc_clean_quality` (
                                    `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                    `project_id` int(11) NOT NULL,
                                    `tag` varchar(20) NOT NULL DEFAULT '' COMMENT '清洗批次',
                                    `item` varchar(50) NOT NULL DEFAULT '' COMMENT '点位名',
                                    `describe` varchar(512) NOT NULL DEFAULT '' COMMENT '数据质量描述',
                                    `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                    PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                    UNIQUE KEY `project_id` (`project_id`,`tag`,`item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=690001 COMMENT='清洗数据的质量统计' /*T![ttl] TTL=`c_time` + INTERVAL 60 DAY */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_device_bind'
CREATE TABLE `dc_device_bind` (
                                  `id` int(11) NOT NULL AUTO_INCREMENT,
                                  `project_id` int(11) NOT NULL,
                                  `name` varchar(50) NOT NULL DEFAULT '' COMMENT '关系名',
                                  `device_code` varchar(50) NOT NULL DEFAULT '' COMMENT '关键设备指标',
                                  `device_type` varchar(20) NOT NULL DEFAULT '' COMMENT '设备类型',
                                  `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '当前状态 0: 禁用 1: 正常',
                                  `items` text NOT NULL COMMENT '相关点位集合',
                                  `target_table` varchar(50) NOT NULL DEFAULT '' COMMENT '数据存入目标表名',
                                  PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                  KEY `project_id_2` (`project_id`,`device_type`),
                                  UNIQUE KEY `project_id` (`project_id`,`device_code`,`device_type`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=60001 COMMENT='相关点位绑定表';

-- Create syntax for TABLE 'dc_device_relation'
CREATE TABLE `dc_device_relation` (
                                      `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                      `project_id` int(11) NOT NULL,
                                      `device_code` varchar(20) NOT NULL DEFAULT '',
                                      `chest` json NOT NULL COMMENT '与之相关的 chest 设备',
                                      `pump` json NOT NULL COMMENT '与之相关的 pump 设备',
                                      `value` json NOT NULL COMMENT '与之相关的 value 设备',
                                      PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                      UNIQUE KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin;

-- Create syntax for TABLE 'dc_event_bind'
CREATE TABLE `dc_event_bind` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL COMMENT '项目 ID',
                                 `device_code` varchar(50) NOT NULL DEFAULT '' COMMENT '设备位号',
                                 `name` varchar(20) NOT NULL DEFAULT '' COMMENT '事件名称',
                                 `item` varchar(50) NOT NULL DEFAULT '' COMMENT '点位名称',
                                 `rule_flag` varchar(20) NOT NULL DEFAULT '' COMMENT '绑定的事件引擎',
                                 `config` varchar(1024) NOT NULL DEFAULT '' COMMENT '事件配置 一个 json 配置，用于',
                                 `interval` int(11) NOT NULL DEFAULT '0' COMMENT '检测时间间隔',
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 UNIQUE KEY `project_id` (`project_id`,`item`,`name`),
                                 KEY `project_id_2` (`project_id`,`rule_flag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=150001;

-- Create syntax for TABLE 'dc_event_list'
CREATE TABLE `dc_event_list` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(50) NOT NULL DEFAULT '',
                                 `name` varchar(50) NOT NULL DEFAULT '' COMMENT '事件名称',
                                 `item` varchar(50) NOT NULL DEFAULT '',
                                 `val` varchar(20) NOT NULL DEFAULT '' COMMENT '事件发生时，点位的值',
                                 `old_val` varchar(20) NOT NULL DEFAULT '' COMMENT '事件发生时, 旧的点位值',
                                 `time` timestamp NOT NULL COMMENT '事件触发时间',
                                 `event_id` int(11) NOT NULL COMMENT '事件 ID dc_event_bind.id',
                                 `title` varchar(100) NOT NULL DEFAULT '' COMMENT '事件标题',
                                 `context` varchar(255) NOT NULL DEFAULT '' COMMENT '事件内容',
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=30001 /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_event_rule'
CREATE TABLE `dc_event_rule` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `name` varchar(20) NOT NULL DEFAULT '' COMMENT '识别事件的处理名称',
                                 `flag` varchar(20) NOT NULL DEFAULT '' COMMENT '唯一标识，应该被程序定义为常量',
                                 `remark` varchar(255) NOT NULL DEFAULT '' COMMENT '说明信息',
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '创建时间',
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 UNIQUE KEY `flag` (`flag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=30001;

-- Create syntax for TABLE 'dc_item_config'
CREATE TABLE `dc_item_config` (
                                  `id` int(10) NOT NULL AUTO_INCREMENT,
                                  `project_id` int(10) NOT NULL,
                                  `device_code` varchar(55) NOT NULL COMMENT '位号',
                                  `item_name` varchar(100) NOT NULL COMMENT '点位名',
                                  `item_alias` varchar(55) NOT NULL COMMENT '别名',
                                  `min_val` decimal(10,4) NOT NULL DEFAULT '0' COMMENT '量程最小值',
                                  `max_val` decimal(10,4) NOT NULL DEFAULT '0' COMMENT '量程最大值',
                                  `item_precision` tinyint(1) NOT NULL COMMENT '精度',
                                  `item_unit` varchar(30) NOT NULL COMMENT '单位',
                                  `create_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                  PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                  KEY `idx_project_item` (`project_id`,`item_name`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=90001 COMMENT='点位量程';

-- Create syntax for TABLE 'dc_item_data'
CREATE TABLE `dc_item_data` (
                                `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                `project_id` int(11) NOT NULL,
                                `item` varchar(50) NOT NULL DEFAULT '',
                                `val` varchar(30) NOT NULL DEFAULT '',
                                `htime` timestamp NOT NULL,
                                `tag` varchar(20) NOT NULL DEFAULT '',
                                PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                KEY `project_id` (`project_id`,`item`),
                                KEY `tag` (`tag`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=44424777 /*T![ttl] TTL=`htime` + INTERVAL 60 DAY */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_item_history_data_46'
CREATE TABLE `dc_item_history_data_46` (
                                           `item_name` varchar(100) NOT NULL DEFAULT '' COMMENT '点位名',
                                           `val` decimal(12,6) NOT NULL DEFAULT '0' COMMENT '值',
                                           `h_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '采集数据时间',
                                           PRIMARY KEY (`item_name`,`h_time`) /*T![clustered_index] CLUSTERED */
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin COMMENT='单点位秒级历史数据' /*T![ttl] TTL=`h_time` + INTERVAL 12 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_item_history_data_84'
CREATE TABLE `dc_item_history_data_84` (
                                           `item_name` varchar(100) NOT NULL DEFAULT '' COMMENT '点位名',
                                           `val` decimal(12,6) NOT NULL DEFAULT '0' COMMENT '值',
                                           `h_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '采集数据时间',
                                           PRIMARY KEY (`item_name`,`h_time`) /*T![clustered_index] CLUSTERED */
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin COMMENT='单点位秒级历史数据' /*T![ttl] TTL=`h_time` + INTERVAL 12 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_item_history_data_92'
CREATE TABLE `dc_item_history_data_92` (
                                           `item_name` varchar(100) NOT NULL DEFAULT '' COMMENT '点位名',
                                           `val` decimal(12,6) NOT NULL DEFAULT '0' COMMENT '值',
                                           `h_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP COMMENT '采集数据时间',
                                           PRIMARY KEY (`item_name`,`h_time`) /*T![clustered_index] CLUSTERED */
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin COMMENT='单点位秒级历史数据' /*T![ttl] TTL=`h_time` + INTERVAL 12 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_item_map'
CREATE TABLE `dc_item_map` (
                               `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                               `project_id` int(11) NOT NULL COMMENT '项目 ID',
                               `device_code` varchar(20) NOT NULL DEFAULT '' COMMENT '设备位号',
                               `source_item` varchar(50) NOT NULL DEFAULT '' COMMENT '来源 item 名',
                               `target_item` varchar(50) NOT NULL DEFAULT '' COMMENT '目标item 名，也就是数据中心的 item 名',
                               `alias` varchar(255) NOT NULL DEFAULT '' COMMENT '点位名描述',
                               PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                               UNIQUE KEY `project_id` (`project_id`,`source_item`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=60001;

-- Create syntax for TABLE 'dc_project_config'
CREATE TABLE `dc_project_config` (
                                     `id` int(10) unsigned NOT NULL AUTO_INCREMENT,
                                     `project_id` int(11) NOT NULL,
                                     `technologys` varchar(1024) CHARACTER SET utf8 COLLATE utf8_general_ci NOT NULL DEFAULT '' COMMENT '该项目中要使用的项目 ["A","B"]',
                                     `status` tinyint(4) NOT NULL DEFAULT '0' COMMENT '项目状态  0：禁用 1： 正常',
                                     `m_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
                                     PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                     UNIQUE KEY `project_id` (`project_id`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_general_ci AUTO_INCREMENT=60001;

-- Create syntax for TABLE 'dc_working_chest'
CREATE TABLE `dc_working_chest` (
                                    `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                    `project_id` int(11) NOT NULL,
                                    `device_code` varchar(20) NOT NULL DEFAULT '',
                                    `switch` tinyint(4) NOT NULL DEFAULT '0' COMMENT '药箱液位开关 0： 关 1： 开',
                                    `level` decimal(6,4) NOT NULL DEFAULT '0' COMMENT '液位高度',
                                    `agitator_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '搅拌器运行状态 0： 未运行 1：运行中',
                                    `agitator_duration` int(11) NOT NULL DEFAULT '0' COMMENT '搅拌器运行时长',
                                    `agitator_fault_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '搅拌器故障状态 0：正常 1：故障',
                                    `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                    PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                    KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=42750001 COMMENT='药箱液位' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_working_mf'
CREATE TABLE `dc_working_mf` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(20) NOT NULL DEFAULT '',
                                 `water_temperature` decimal(4,2) NOT NULL DEFAULT '0' COMMENT '水温 摄氏度',
                                 `feed_flow` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水流量',
                                 `con_flow` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '浓水流量',
                                 `product_flow` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水流量',
                                 `feed_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水压力',
                                 `con_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '浓水压力',
                                 `product_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水压力',
                                 `tmp` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '跨膜压差',
                                 `flux` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '膜通量',
                                 `feed_wq_turbidity` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水浊度',
                                 `feed_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '进水 PH 值',
                                 `product_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '产水 PH 值',
                                 `feed_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铝',
                                 `product_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铝',
                                 `feed_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铁',
                                 `product_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铁',
                                 `feed_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：锰',
                                 `product_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：锰',
                                 `feed_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：二氧化硅',
                                 `product_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：二氧化硅',
                                 `feed_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：COD',
                                 `product_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：COD',
                                 `feed_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：磷',
                                 `product_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：磷',
                                 `step` int(11) DEFAULT NULL COMMENT '设备当前步序值',
                                 `filter_time` decimal(8,2) DEFAULT NULL,
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin COMMENT='微滤' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_working_nf'
CREATE TABLE `dc_working_nf` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(20) NOT NULL DEFAULT '',
                                 `water_temperature` decimal(4,2) NOT NULL DEFAULT '0' COMMENT '水温 摄氏度',
                                 `feed_flow_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段进水流量',
                                 `con_flow_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段浓水流量',
                                 `product_flow_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段产水流量',
                                 `feed_pressure_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段进水压力',
                                 `con_pressure_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段浓水压力',
                                 `product_pressure_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段产水压力',
                                 `tmp_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段跨膜压差',
                                 `flux_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段膜通量',
                                 `permeability_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段渗透率',
                                 `feed_flow_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段进水流量',
                                 `con_flow_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段浓水流量',
                                 `product_flow_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段产水流量',
                                 `feed_pressure_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段进水压力',
                                 `con_pressure_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段浓水压力',
                                 `product_pressure_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段产水压力',
                                 `tmp_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段压差',
                                 `flux_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段通量',
                                 `permeability_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段渗透率',
                                 `feed_flow_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段进水流量',
                                 `con_flow_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段浓水流量',
                                 `product_flow_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段产水流量',
                                 `feed_pressure_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段进水压力',
                                 `con_pressure_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段浓水压力',
                                 `product_pressure_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段产水压力',
                                 `tmp_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段压差',
                                 `flux_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段通量',
                                 `permeability_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段渗透率',
                                 `feed_wq_turbidity` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水浊度',
                                 `feed_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '进水 PH 值',
                                 `product_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '产水 PH 值',
                                 `feed_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铝',
                                 `product_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铝',
                                 `feed_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铁',
                                 `product_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铁',
                                 `feed_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：锰',
                                 `product_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：锰',
                                 `feed_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：二氧化硅',
                                 `product_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：二氧化硅',
                                 `feed_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：COD',
                                 `product_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：COD',
                                 `feed_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：磷',
                                 `product_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：磷',
                                 `step` int(11) DEFAULT NULL COMMENT '设备当前步序值',
                                 `filter_time` decimal(8,2) DEFAULT NULL,
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin COMMENT='纳滤' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_working_pump'
CREATE TABLE `dc_working_pump` (
                                   `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                   `project_id` int(11) NOT NULL,
                                   `device_code` varchar(20) NOT NULL DEFAULT '',
                                   `feed_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水压力',
                                   `out_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '出水压力',
                                   `duration` int(11) NOT NULL DEFAULT '0' COMMENT '运行时长 单位 s',
                                   `current` decimal(5,2) NOT NULL DEFAULT '0' COMMENT '运行电流 ',
                                   `frequency` decimal(4,2) NOT NULL DEFAULT '0' COMMENT '运行频率',
                                   `lift` decimal(5,2) NOT NULL DEFAULT '0' COMMENT '工作扬程',
                                   `efficiency` decimal(4,2) NOT NULL DEFAULT '0' COMMENT '运行效率',
                                   `run_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '运行状态 0： 停机 1： 运行正常',
                                   `fault_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '故障状态 0： 正常 1： 故障',
                                   `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                   PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                   KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=79500001 COMMENT='水泵' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_working_ro'
CREATE TABLE `dc_working_ro` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(20) NOT NULL DEFAULT '',
                                 `water_temperature` decimal(4,2) NOT NULL DEFAULT '0' COMMENT '水温 摄氏度',
                                 `feed_flow_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段进水流量',
                                 `con_flow_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段浓水流量',
                                 `product_flow_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段产水流量',
                                 `feed_pressure_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段进水压力',
                                 `con_pressure_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段浓水压力',
                                 `product_pressure_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段产水压力',
                                 `tmp_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段跨膜压差',
                                 `flux_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段膜通量',
                                 `permeability_1st` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '一段渗透率',
                                 `feed_flow_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段进水流量',
                                 `con_flow_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段浓水流量',
                                 `product_flow_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段产水流量',
                                 `feed_pressure_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段进水压力',
                                 `con_pressure_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段浓水压力',
                                 `product_pressure_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段产水压力',
                                 `tmp_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段压差',
                                 `flux_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段通量',
                                 `feed_flow_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段进水流量',
                                 `con_flow_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段浓水流量',
                                 `product_flow_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段产水流量',
                                 `feed_pressure_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段进水压力',
                                 `con_pressure_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段浓水压力',
                                 `product_pressure_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段产水压力',
                                 `tmp_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段压差',
                                 `flux_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段通量',
                                 `permeability_3th` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '三段渗透率',
                                 `feed_wq_turbidity` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水浊度',
                                 `feed_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '进水 PH 值',
                                 `product_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '产水 PH 值',
                                 `permeability_2nd` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '二段渗透率',
                                 `feed_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铝',
                                 `product_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铝',
                                 `feed_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铁',
                                 `product_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铁',
                                 `feed_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：锰',
                                 `product_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：锰',
                                 `feed_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：二氧化硅',
                                 `product_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：二氧化硅',
                                 `feed_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：COD',
                                 `product_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：COD',
                                 `feed_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：磷',
                                 `product_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：磷',
                                 `step` int(11) DEFAULT NULL COMMENT '设备当前步序值',
                                 `filter_time` decimal(8,2) DEFAULT NULL,
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=11880001 COMMENT='反渗透' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_working_uf'
CREATE TABLE `dc_working_uf` (
                                 `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                 `project_id` int(11) NOT NULL,
                                 `device_code` varchar(20) NOT NULL DEFAULT '',
                                 `water_temperature` decimal(4,2) NOT NULL DEFAULT '0' COMMENT '水温 摄氏度',
                                 `feed_flow` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水流量',
                                 `con_flow` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '浓水流量',
                                 `product_flow` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水流量',
                                 `feed_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水压力',
                                 `con_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '浓水压力',
                                 `product_pressure` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水压力',
                                 `tmp` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '跨膜压差',
                                 `flux` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '膜通量',
                                 `feed_wq_turbidity` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水浊度',
                                 `feed_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '进水 PH 值',
                                 `product_wq_ph` tinyint(4) NOT NULL DEFAULT '0' COMMENT '产水 PH 值',
                                 `feed_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铝',
                                 `product_wq_al` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铝',
                                 `feed_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：铁',
                                 `product_wq_fe` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：铁',
                                 `feed_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：锰',
                                 `product_wq_mn` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：锰',
                                 `feed_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：二氧化硅',
                                 `product_wq_sio2` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：二氧化硅',
                                 `feed_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：COD',
                                 `product_wq_cod` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：COD',
                                 `feed_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '进水水质：磷',
                                 `product_wq_p` decimal(8,4) NOT NULL DEFAULT '0' COMMENT '产水水质：磷',
                                 `step` int(11) DEFAULT NULL COMMENT '设备当前步序值',
                                 `filter_time` decimal(8,2) DEFAULT NULL,
                                 `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                 PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                 KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=11970001 COMMENT='超滤' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;

-- Create syntax for TABLE 'dc_working_valve'
CREATE TABLE `dc_working_valve` (
                                    `id` int(11) unsigned NOT NULL AUTO_INCREMENT,
                                    `project_id` int(11) NOT NULL,
                                    `device_code` varchar(20) NOT NULL DEFAULT '',
                                    `adjust` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否为调节阀门 0： 否 1： 是',
                                    `opening` decimal(8,2) NOT NULL DEFAULT '0' COMMENT '当前阀门的开度',
                                    `closed` tinyint(1) NOT NULL DEFAULT '0' COMMENT '关到位 全关  0: 否 1： 是',
                                    `opened` tinyint(1) NOT NULL DEFAULT '0' COMMENT '开到位 开到 设置的开度 0: 否 1： 是',
                                    `fault_status` tinyint(1) NOT NULL DEFAULT '0' COMMENT '是否故障 0: 否 1： 是',
                                    `c_time` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
                                    PRIMARY KEY (`id`) /*T![clustered_index] CLUSTERED */,
                                    KEY `project_id` (`project_id`,`device_code`)
) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_bin AUTO_INCREMENT=27630001 COMMENT='阀门' /*T![ttl] TTL=`c_time` + INTERVAL 3 MONTH */ /*T![ttl] TTL_ENABLE='ON' */ /*T![ttl] TTL_JOB_INTERVAL='1h' */;